@@ -11,12 +11,12 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, List
+from typing import List
+
+from botocore.response import StreamingBody
+
+from mypy_boto3_mediastore_data.literals import ItemType, StorageClass
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -36,7 +36,7 @@ ItemTypeDef = TypedDict(
     "ItemTypeDef",
     {
         "Name": str,
-        "Type": Literal["OBJECT", "FOLDER"],
+        "Type": ItemType,
         "ETag": str,
         "LastModified": datetime,
         "ContentType": str,
@@ -63,7 +63,7 @@ _RequiredGetObjectResponseTypeDef = TypedDict(
 _OptionalGetObjectResponseTypeDef = TypedDict(
     "_OptionalGetObjectResponseTypeDef",
     {
-        "Body": IO[bytes],
+        "Body": StreamingBody,
         "CacheControl": str,
         "ContentRange": str,
         "ContentLength": int,
@@ -91,6 +91,6 @@ PaginatorConfigTypeDef = TypedDict(
 
 PutObjectResponseTypeDef = TypedDict(
     "PutObjectResponseTypeDef",
-    {"ContentSHA256": str, "ETag": str, "StorageClass": Literal["TEMPORAL"]},
+    {"ContentSHA256": str, "ETag": str, "StorageClass": StorageClass},
     total=False,
 )
